@@ -8,4 +8,4 @@ from viur.datastore.transport import Get, Put, Delete, RunInTransaction, Collisi
 __all__ = ["KEY_SPECIAL_PROPERTY", "DATASTORE_BASE_TYPES", "SortOrder", "SkelListRef", "Entity", "QueryDefinition",
 		   "Key", "Query", "fixUnindexableProperties", "normalizeKey", "keyHelper", "Get", "Put", "Delete",
 		   "RunInTransaction", "IsInTransaction", "currentDbAccessLog", "GetOrInsert", "encodeKey",
-		   "acquireTransactionSuccessMarker", "Collision"]
+		   "acquireTransactionSuccessMarker", "Collision", "AllocateIDs"]
